@@ -28,29 +28,29 @@
   "return DateTime instance from string using
    formatters in clj-time.format, returning first
    which parses"
-  [s]
-  (first
-   (for [f (vals time-fmt/formatters)
-         :let [d (try (time-fmt/parse f s) (catch Exception _ nil))]
-         :when d] d)))
+  [^String s]
+  (time-fmt/parse s))
 
 (defn from-date
   "Returns a DateTime instance in the UTC time zone corresponding to the given
    Java Date object."
   [^Date date]
-  (from-long (.getTime date)))
+  (when date
+    (from-long (.getTime date))))
 
 (defn from-sql-date
   "Returns a DateTime instance in the UTC time zone corresponding to the given
    java.sql.Date object."
   [^java.sql.Date sql-date]
-  (from-long (.getTime sql-date)))
+  (when sql-date
+    (from-long (.getTime sql-date))))
 
 (defn from-sql-time
   "Returns a DateTime instance in the UTC time zone corresponding to the given
    java.sql.Timestamp object."
   [^java.sql.Timestamp sql-time]
-  (from-long (.getTime sql-time)))
+  (when sql-time
+    (from-long (.getTime sql-time))))
 
 (defn to-long
   "Convert `obj` to the number of milliseconds after the Unix epoch."
@@ -62,7 +62,7 @@
   "Convert `obj` to Unix epoch."
   [obj]
   (let [millis (to-long obj)]
-    (and millis (/ millis 1000))))
+    (and millis (quot millis 1000))))
 
 (defn to-date
   "Convert `obj` to a Java Date instance."
