@@ -114,16 +114,16 @@ function task_install {
     install -d -m 0755 "${DESTDIR}${app_prefix}"
     install -d -m 0755 "${DESTDIR}${app_data}"
     install -m 0644 puppet-server-release.jar "${DESTDIR}${app_prefix}"
-    install -m 0750 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
+    install -m 0755 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
     install -m 0644 ext/ezbake.manifest "${DESTDIR}${app_prefix}"
     install -d -m 0755 "${DESTDIR}${projconfdir}/conf.d"
     install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
-    install -m 0644 ext/config/conf.d/ca.conf "${DESTDIR}${projconfdir}/conf.d/ca.conf"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
     install -m 0644 ext/config/bootstrap.cfg "${DESTDIR}${projconfdir}/bootstrap.cfg"
     install -m 0644 ext/config/conf.d/global.conf "${DESTDIR}${projconfdir}/conf.d/global.conf"
     install -m 0644 ext/config/conf.d/web-routes.conf "${DESTDIR}${projconfdir}/conf.d/web-routes.conf"
+    install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
     install -m 0644 ext/config/conf.d/webserver.conf "${DESTDIR}${projconfdir}/conf.d/webserver.conf"
     install -d -m 0755 "${DESTDIR}${app_prefix}/scripts"
     install -m 0755 install.sh "${DESTDIR}${app_prefix}/scripts"
