@@ -1,7 +1,7 @@
 (def tk-version "1.1.1")
 (def tk-jetty-version "1.3.1")
 (def ks-version "1.1.0")
-(def ps-version "2.1.2")
+(def ps-version "2.2.0")
 
 (defn deploy-info
   [url]
@@ -14,7 +14,15 @@
   :description "Puppet Server"
 
   :dependencies [[org.clojure/clojure "1.6.0"]
+
+                 ;; begin version conflict resolution dependencies
+                 [puppetlabs/typesafe-config "0.1.4"]
+                 [org.clojure/tools.reader "0.9.1"]
+                 [ring/ring-core "1.4.0"]
+                 ;; end version conflict resolution dependencies
+
                  [puppetlabs/trapperkeeper ~tk-version]
+                 [puppetlabs/trapperkeeper-authorization "0.5.0"]
                  [puppetlabs/kitchensink ~ks-version]
                  [puppetlabs/ssl-utils "0.8.1"]
                  [puppetlabs/dujour-version-check "0.1.2" :exclusions [org.clojure/tools.logging]]
@@ -33,8 +41,8 @@
                  [org.jruby/jruby-stdlib "1.7.20.1"]
                  [org.clojure/data.json "0.2.3"]
                  [org.clojure/tools.macro "0.1.5"]
-                 [joda-time "2.5"]
-                 [clj-time "0.7.0"]
+                 [joda-time "2.7"]
+                 [clj-time "0.10.0"]
                  [liberator "0.12.0"]
                  [puppetlabs/comidi "0.1.1"]
                  [me.raynes/fs "1.4.5"]
@@ -84,7 +92,7 @@
   :classifiers [["test" :testutils]]
 
   :profiles {:dev {:source-paths  ["dev"]
-                   :dependencies  [[org.clojure/tools.namespace "0.2.4"]
+                   :dependencies  [[org.clojure/tools.namespace "0.2.5"]
                                    [puppetlabs/trapperkeeper-webserver-jetty9 ~tk-jetty-version]
                                    [puppetlabs/trapperkeeper-webserver-jetty9 ~tk-jetty-version :classifier "test"]
                                    [puppetlabs/trapperkeeper ~tk-version :classifier "test" :scope "test"]
@@ -102,7 +110,7 @@
              :ezbake {:dependencies ^:replace [[puppetlabs/puppetserver ~ps-version]
                                                [puppetlabs/trapperkeeper-webserver-jetty9 ~tk-jetty-version]
                                                [org.clojure/tools.nrepl "0.2.3"]]
-                      :plugins [[puppetlabs/lein-ezbake "0.3.16"]]
+                      :plugins [[puppetlabs/lein-ezbake "0.3.21"]]
                       :name "puppetserver"}
              :uberjar {:aot [puppetlabs.trapperkeeper.main]
                        :dependencies [[puppetlabs/trapperkeeper-webserver-jetty9 ~tk-jetty-version]]}
@@ -117,7 +125,7 @@
             "irb" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.irb"]}
 
   ; tests use a lot of PermGen (jruby instances)
-  :jvm-opts ["-XX:MaxPermSize=256m" "-Xmx1024M"]
+  :jvm-opts ["-XX:MaxPermSize=256m" "-Xmx2g"]
 
   :repl-options {:init-ns user}
 
