@@ -15,6 +15,8 @@ import java.util.Map;
  *
  */
 public interface JRubyPuppet {
+    Map<String, Map> getClassInfoForAllEnvironments();
+    Map getClassInfoForEnvironment(String environment);
     JRubyPuppetResponse handleRequest(Map request);
     Object getSetting(String setting);
     String puppetVersion();
