@@ -37,9 +37,15 @@
 
 (defn build-ring-handler
   [settings puppet-version]
-  (-> (web-routes settings)
-      (comidi/routes->handler)
-      (wrap-middleware puppet-version)))
+  (get-wrapped-handler
+    (-> (web-routes settings)
+        (comidi/routes->handler))
+    settings
+    ""
+    (fn [handler]
+      (fn [request]
+        (handler request)))
+    puppet-version))
 
 (defn wrap-with-ssl-client-cert
   "Wrap a compojure app so all requests will include the
@@ -615,7 +621,7 @@
   (testing "a request with a certificate not on the whitelist is rejected"
     (let [settings (assoc (testutils/ca-settings cadir)
                      :access-control {:certificate-status
-                                      {:client-whitelist []}})
+                                      {:client-whitelist ["not-localhost"]}})
           test-app (build-ring-handler settings "1.2.3.4")]
       (doseq [endpoint ["certificate_status" "certificate_statuses"]]
         (testing endpoint
