@@ -14,7 +14,8 @@
             [puppetlabs.services.jruby.jruby-puppet-agents :as jruby-agents]
             [puppetlabs.trapperkeeper.testutils.logging :as logutils])
   (:import (puppetlabs.services.jruby.jruby_puppet_schemas RetryPoisonPill)
-           (com.puppetlabs.puppetserver JRubyPuppet RegisteredLinkedBlockingDeque)))
+           (com.puppetlabs.puppetserver JRubyPuppet)
+           (com.puppetlabs.puppetserver.pool JRubyPool)))
 
 (use-fixtures :once schema-test/validate-schemas)
 (use-fixtures :each jruby-testutils/mock-pool-instance-fixture)
@@ -87,10 +88,10 @@
             real-pool     (-> (tk-services/service-context jruby-service)
                               :pool-context
                               (jruby-core/get-pool))
-            retry-pool    (RegisteredLinkedBlockingDeque. 1)
-            _             (-> retry-pool
+            retry-pool    (JRubyPool. 1)
+            _             (->> retry-pool
                               (RetryPoisonPill.)
-                              (jruby-core/return-to-pool :test []))
+                              (.insertPill retry-pool))
             mock-pools    [retry-pool retry-pool retry-pool real-pool]
             num-borrows   (atom 0)
             get-mock-pool (fn [_] (let [result (nth mock-pools @num-borrows)]
