@@ -1,9 +1,9 @@
 (ns puppetlabs.services.jruby.jruby-puppet-schemas
   (:require [schema.core :as schema]
             [puppetlabs.services.jruby.puppet-environments :as puppet-env])
-  (:import (java.util.concurrent BlockingDeque)
-           (clojure.lang Atom Agent IFn PersistentArrayMap PersistentHashMap)
+  (:import (clojure.lang Atom Agent IFn PersistentArrayMap PersistentHashMap)
            (com.puppetlabs.puppetserver PuppetProfiler JRubyPuppet EnvironmentRegistry)
+           (com.puppetlabs.puppetserver.pool LockablePool)
            (org.jruby Main Main$Status)
            (org.jruby.embed ScriptingContainer)))
 
@@ -13,7 +13,7 @@
 (def pool-queue-type
   "The Java datastructure type used to store JRubyPuppet instances which are
   free to be borrowed."
-  BlockingDeque)
+  LockablePool)
 
 (defrecord PoisonPill
   ;; A sentinel object to put into a pool in case an error occurs while we're trying
@@ -71,7 +71,11 @@
         milliseconds, that an outbound HTTP connection will wait for data to be
         available after a request is sent before closing the socket.  If 0, the
         timeout is infinite and if negative, the value is undefined by the
-        application and is governed by the default system behavior."
+        application and is governed by the default system behavior.
+
+    * :use-legacy-auth-conf - Whether to use the legacy core Puppet auth.conf
+        (true) or trapperkeeper-authorization (false) to authorize requests
+        being made to core Puppet endpoints."
   ;; NOTE: there is a bug in the version of schema we're using, which causes
   ;; the order of things that you put into a `both` to be very important.
   ;; The `vector?` pred here MUST come before the `[schema/Str]`.  For more info
@@ -89,7 +93,8 @@
    :http-client-idle-timeout-milliseconds    schema/Int
    :borrow-timeout              schema/Int
    :max-active-instances        schema/Int
-   :max-requests-per-instance   schema/Int})
+   :max-requests-per-instance   schema/Int
+   :use-legacy-auth-conf        schema/Bool})
 
 (def JRubyPoolAgent
   "An agent configured for use in managing JRuby pools"
@@ -207,6 +212,18 @@
   [e]
   (= :instance-returned (:type e)))
 
+(defn event-type-lock-requested?
+  [e]
+  (= :lock-requested (:type e)))
+
+(defn event-type-lock-acquired?
+  [e]
+  (= :lock-acquired (:type e)))
+
+(defn event-type-lock-released?
+  [e]
+  (= :lock-released (:type e)))
+
 (def JRubyEventReason
   schema/Any)
 
@@ -225,8 +242,23 @@
    :reason JRubyEventReason
    :instance JRubyPuppetInstanceOrRetry})
 
+(def JRubyLockRequestedEvent
+  {:type (schema/eq :lock-requested)
+   :reason JRubyEventReason})
+
+(def JRubyLockAcquiredEvent
+  {:type (schema/eq :lock-acquired)
+   :reason JRubyEventReason})
+
+(def JRubyLockReleasedEvent
+  {:type (schema/eq :lock-released)
+   :reason JRubyEventReason})
+
 (def JRubyEvent
   (schema/conditional
     event-type-requested? JRubyRequestedEvent
     event-type-borrowed? JRubyBorrowedEvent
-    event-type-returned? JRubyReturnedEvent))
+    event-type-returned? JRubyReturnedEvent
+    event-type-lock-requested? JRubyLockRequestedEvent
+    event-type-lock-acquired? JRubyLockAcquiredEvent
+    event-type-lock-released? JRubyLockReleasedEvent))
