@@ -24,15 +24,14 @@
     (doseq [[method paths]
             {:get ["catalog"
                    "node"
-                   "facts"
+                   "environment"
                    "file_content"
                    "file_metadatas"
                    "file_metadata"
                    "file_bucket_file"
                    "resource_type"
                    "resource_types"
-                   "status"
-                   "facts_search"]
+                   "status"]
              :post ["catalog"]
              :put ["file_bucket_file"
                    "report"]
